//
//  SampleView.m
//  OneScreenSample
//

#import "SampleView.h"
#import <QuartzCore/QuartzCore.h>


@implementation SampleView

@synthesize	image;

- (id)initWithFrame:(CGRect)frame {
    if ((self = [super initWithFrame:frame])) {
		label = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, 300, 20)];
		label.text = @"Flip";
		[self addSubview:label];
		label.center = CGPointMake(160, 420);
		[label release];
    }
    return self;
}

- (void)drawRect:(CGRect)rect {
	[image drawInRect:rect blendMode:kCGBlendModeNormal alpha:1.0];
}

- (void)dealloc {
	[image release];
    [super dealloc];
}


-(void) touchesEnded:(NSSet *)touches withEvent:(UIEvent *)event
{
	if(self.tag){
		self.tag = 0;
		self.image = [UIImage imageNamed:@"imageA.png"];
	}
	else {
		self.tag = 1;
		self.image = [UIImage imageNamed:@"imageB.png"];
	}
	[self setNeedsDisplay];
	
	//切り替え演出
	switch (count) 
	{
		case 0:
		{
			//Flip
			[UIView beginAnimations:@"FlipAnime" context:nil];
			[UIView setAnimationDuration:0.8];
			[UIView setAnimationTransition:UIViewAnimationTransitionFlipFromLeft forView:[self superview] cache:YES];
			[UIView commitAnimations];
			label.text = @"CurlUp";
		}break;
			
		case 1:
		{
			//CurlUp
			[UIView beginAnimations:@"CurlUpAnime" context:nil];
			[UIView setAnimationDuration:0.8];
			[UIView setAnimationTransition:UIViewAnimationTransitionCurlUp forView:[self superview] cache:YES];
			[UIView commitAnimations];
			label.text = @"Fade";
		}break;
			
		case 2:
		{
			//フェード
			CATransition *anime = [CATransition animation];
			[anime setType:kCATransitionFade];
			[anime setDuration:0.4];// 持続時間
			[anime setTimingFunction:[CAMediaTimingFunction functionWithName:kCAMediaTimingFunctionEaseInEaseOut]];
			[[self layer] addAnimation:anime forKey:kCATransition];// レイヤークラスに設定
			label.text = @"MoveIn";
		}break;
			
		case 3:
		{
			//MoveIn
			CATransition *anime = [CATransition animation];
			[anime setType:kCATransitionMoveIn];
			[anime setSubtype:kCATransitionFromLeft];
			[anime setDuration:0.4];// 持続時間
			[anime setTimingFunction:[CAMediaTimingFunction functionWithName:kCAMediaTimingFunctionEaseInEaseOut]];
			[[self layer] addAnimation:anime forKey:kCATransition];// レイヤークラスに設定
			label.text = @"Push";
		}break;
			
		case 4:
		{
			//Push
			CATransition *anime = [CATransition animation];
			[anime setType:kCATransitionPush];
			[anime setSubtype:kCATransitionFromLeft];
			[anime setDuration:0.4];// 持続時間
			[anime setTimingFunction:[CAMediaTimingFunction functionWithName:kCAMediaTimingFunctionEaseInEaseOut]];
			[[self layer] addAnimation:anime forKey:kCATransition];// レイヤークラスに設定
			label.text = @"Reveal";
		}break;
			
		case 5:
		{
			//Reveal
			CATransition *anime = [CATransition animation];
			[anime setType:kCATransitionReveal];
			[anime setSubtype:kCATransitionFromLeft];
			[anime setDuration:0.4];// 持続時間
			[anime setTimingFunction:[CAMediaTimingFunction functionWithName:kCAMediaTimingFunctionEaseInEaseOut]];
			[[self layer] addAnimation:anime forKey:kCATransition];// レイヤークラスに設定
			label.text = @"bounds";
		}break;
			
		case 6:
		{
			//bounds
			float	scl1=1.0;
			float	scl2=8.0;
			CABasicAnimation*	anime = [CABasicAnimation animationWithKeyPath:@"bounds"];
			//anime.duration = 0.8;
			CGRect	fromRect = CGRectMake(self.layer.bounds.origin.x, self.layer.bounds.origin.y, self.layer.bounds.size.width*scl1, self.layer.bounds.size.height*scl1);
			CGRect	toRect   = CGRectMake(self.layer.bounds.origin.x, self.layer.bounds.origin.y, self.layer.bounds.size.width*scl2, self.layer.bounds.size.height*scl2);
			anime.fromValue = [NSValue valueWithCGRect:fromRect];
			anime.toValue   = [NSValue valueWithCGRect:toRect];		
			[self.layer addAnimation:anime forKey:@"bounds"];
			label.text = @"Rotation";
		}break;
			
		case 7:
		{
			//rotation
			//低速〜高速〜低速
			[CATransaction setAnimationTimingFunction:
					[CAMediaTimingFunction functionWithName:kCAMediaTimingFunctionEaseInEaseOut]];
			CABasicAnimation*	anime = [CABasicAnimation animationWithKeyPath:@"transform.rotation"];
			anime.duration  = 0.8;
			anime.toValue   = [NSNumber numberWithFloat:((360.0*2)*M_PI/180.0)];		
			[self.layer addAnimation:anime forKey:@"rotation"];
			label.text = @"CurlUp";
		}break;
			
			
	}
	
	count++;
	if(count > 7)
		count = 0;
}

@end
